@@ -9,7 +9,7 @@ load_all <- function(path = ".", reset = TRUE, recompile = FALSE,
 
   save_all()
 
-  check_dots_used()
+  check_dots_used(action = getOption("devtools.ellipsis_action", rlang::warn))
 
   pkgload::load_all(
     path = path, reset = reset, recompile = recompile,
@@ -20,9 +20,3 @@ load_all <- function(path = ".", reset = TRUE, recompile = FALSE,
 #' @importFrom pkgload unload
 #' @export
 pkgload::unload
-
-#' @importFrom pkgload check_suggested
-# This is just check_suggested from pkgload with a different default path
-check_suggested <- function(package, version = NULL, compare = NA, path = pkgload::inst("devtools")) {
-  pkgload::check_suggested(package = package, version = version, compare = compare, path = path)
-}
